@@ -24,25 +24,27 @@ namespace ccls {
 void MessageHandler::textDocument_declaration(TextDocumentPositionParam &param,
                                               ReplyOnce &reply) {
   int file_id;
-  auto [file, wf] = FindOrFail(param.textDocument.uri.GetPath(), reply, &file_id);
+  auto [file, wf] =
+      findOrFail(param.textDocument.uri.getPath(), reply, &file_id);
   if (!wf)
     return;
 
   std::vector<LocationLink> result;
   Position &ls_pos = param.position;
-  for (SymbolRef sym : FindSymbolsAtLocation(wf, file, param.position))
-    for (DeclRef dr : GetNonDefDeclarations(db, sym))
+  for (SymbolRef sym : findSymbolsAtLocation(wf, file, param.position))
+    for (DeclRef dr : getNonDefDeclarations(db, sym))
       if (!(dr.file_id == file_id &&
-            dr.range.Contains(ls_pos.line, ls_pos.character)))
-        if (auto loc = GetLocationLink(db, wfiles, dr))
+            dr.range.contains(ls_pos.line, ls_pos.character)))
+        if (auto loc = getLocationLink(db, wfiles, dr))
           result.push_back(loc);
-  reply.ReplyLocationLink(result);
+  reply.replyLocationLink(result);
 }
 
 void MessageHandler::textDocument_definition(TextDocumentPositionParam &param,
                                              ReplyOnce &reply) {
   int file_id;
-  auto [file, wf] = FindOrFail(param.textDocument.uri.GetPath(), reply, &file_id);
+  auto [file, wf] =
+      findOrFail(param.textDocument.uri.getPath(), reply, &file_id);
   if (!wf)
     return;
 
@@ -50,16 +52,16 @@ void MessageHandler::textDocument_definition(TextDocumentPositionParam &param,
   Maybe<DeclRef> on_def;
   Position &ls_pos = param.position;
 
-  for (SymbolRef sym : FindSymbolsAtLocation(wf, file, ls_pos, true)) {
+  for (SymbolRef sym : findSymbolsAtLocation(wf, file, ls_pos, true)) {
     // Special cases which are handled:
     //  - symbol has declaration but no definition (ie, pure virtual)
     //  - goto declaration while in definition of recursive type
     std::vector<DeclRef> drs;
-    EachEntityDef(db, sym, [&](const auto &def) {
+    eachEntityDef(db, sym, [&](const auto &def) {
       if (def.spell) {
         DeclRef spell = *def.spell;
         if (spell.file_id == file_id &&
-            spell.range.Contains(ls_pos.line, ls_pos.character)) {
+            spell.range.contains(ls_pos.line, ls_pos.character)) {
           on_def = spell;
           drs.clear();
           return false;
@@ -72,16 +74,16 @@ void MessageHandler::textDocument_definition(TextDocumentPositionParam &param,
     // |uses| is empty if on a declaration/definition, otherwise it includes
     // all declarations/definitions.
     if (drs.empty()) {
-      for (DeclRef dr : GetNonDefDeclarations(db, sym))
+      for (DeclRef dr : getNonDefDeclarations(db, sym))
         if (!(dr.file_id == file_id &&
-              dr.range.Contains(ls_pos.line, ls_pos.character)))
+              dr.range.contains(ls_pos.line, ls_pos.character)))
           drs.push_back(dr);
       // There is no declaration but the cursor is on a definition.
       if (drs.empty() && on_def)
         drs.push_back(*on_def);
     }
     for (DeclRef dr : drs)
-      if (auto loc = GetLocationLink(db, wfiles, dr))
+      if (auto loc = getLocationLink(db, wfiles, dr))
         result.push_back(loc);
   }
 
@@ -91,7 +93,7 @@ void MessageHandler::textDocument_definition(TextDocumentPositionParam &param,
     for (const IndexInclude &include : file->def->includes) {
       if (include.line == ls_pos.line) {
         result.push_back(
-            {DocumentUri::FromPath(include.resolved_path).raw_uri});
+            {DocumentUri::fromPath(include.resolved_path).raw_uri});
         range = {{0, 0}, {0, 0}};
         break;
       }
@@ -100,7 +102,7 @@ void MessageHandler::textDocument_definition(TextDocumentPositionParam &param,
     if (!range) {
       Position position = param.position;
       const std::string &buffer = wf->buffer_content;
-      std::string_view query = LexIdentifierAroundPos(position, buffer);
+      std::string_view query = lexIdentifierAroundPos(position, buffer);
       std::string_view short_query = query;
       {
         auto pos = query.rfind(':');
@@ -115,13 +117,13 @@ void MessageHandler::textDocument_definition(TextDocumentPositionParam &param,
       SymbolIdx best_sym;
       best_sym.kind = Kind::Invalid;
       auto fn = [&](SymbolIdx sym) {
-        std::string_view short_name = db->GetSymbolName(sym, false),
+        std::string_view short_name = db->getSymbolName(sym, false),
                          name = short_query.size() < query.size()
-                                    ? db->GetSymbolName(sym, true)
+                                    ? db->getSymbolName(sym, true)
                                     : short_name;
         if (short_name != short_query)
           return;
-        if (Maybe<DeclRef> dr = GetDefinitionSpell(db, sym)) {
+        if (Maybe<DeclRef> dr = getDefinitionSpell(db, sym)) {
           std::tuple<int, int, bool, int> score{
               int(name.size() - short_query.size()), 0, dr->file_id != file_id,
               std::abs(dr->range.start.line - position.line)};
@@ -147,46 +149,46 @@ void MessageHandler::textDocument_definition(TextDocumentPositionParam &param,
           fn({var.usr, Kind::Var});
 
       if (best_sym.kind != Kind::Invalid) {
-        Maybe<DeclRef> dr = GetDefinitionSpell(db, best_sym);
+        Maybe<DeclRef> dr = getDefinitionSpell(db, best_sym);
         assert(dr);
-        if (auto loc = GetLocationLink(db, wfiles, *dr))
+        if (auto loc = getLocationLink(db, wfiles, *dr))
           result.push_back(loc);
       }
     }
   }
 
-  reply.ReplyLocationLink(result);
+  reply.replyLocationLink(result);
 }
 
 void MessageHandler::textDocument_typeDefinition(
     TextDocumentPositionParam &param, ReplyOnce &reply) {
-  auto [file, wf] = FindOrFail(param.textDocument.uri.GetPath(), reply);
+  auto [file, wf] = findOrFail(param.textDocument.uri.getPath(), reply);
   if (!file)
     return;
 
   std::vector<LocationLink> result;
-  auto Add = [&](const QueryType &type) {
+  auto add = [&](const QueryType &type) {
     for (const auto &def : type.def)
       if (def.spell)
-        if (auto loc = GetLocationLink(db, wfiles, *def.spell))
+        if (auto loc = getLocationLink(db, wfiles, *def.spell))
           result.push_back(loc);
     if (result.empty())
       for (const DeclRef &dr : type.declarations)
-        if (auto loc = GetLocationLink(db, wfiles, dr))
+        if (auto loc = getLocationLink(db, wfiles, dr))
           result.push_back(loc);
   };
-  for (SymbolRef sym : FindSymbolsAtLocation(wf, file, param.position)) {
+  for (SymbolRef sym : findSymbolsAtLocation(wf, file, param.position)) {
     switch (sym.kind) {
     case Kind::Var: {
-      const QueryVar::Def *def = db->GetVar(sym).AnyDef();
+      const QueryVar::Def *def = db->getVar(sym).anyDef();
       if (def && def->type)
-        Add(db->Type(def->type));
+        add(db->getType(def->type));
       break;
     }
     case Kind::Type: {
-      for (auto &def : db->GetType(sym).def)
+      for (auto &def : db->getType(sym).def)
         if (def.alias_of) {
-          Add(db->Type(def.alias_of));
+          add(db->getType(def.alias_of));
           break;
         }
       break;
@@ -196,6 +198,6 @@ void MessageHandler::textDocument_typeDefinition(
     }
   }
 
-  reply.ReplyLocationLink(result);
+  reply.replyLocationLink(result);
 }
 } // namespace ccls
